import { select, scaleOrdinal, schemeCategory10 } from 'd3';
import { data } from '@Sreelikhith/heart_failure_prediction';
import { observeResize } from '@curran/responsive-axes';
import { parallelCoordinates } from './parallelCoordinates';

const labelMap = {
  Age: 'Age',
  Sex: 'Gender',
  ChestPainType: 'Chest Pain Type',
  RestingBP: 'Resting Blood Pressure',
  Cholesterol: 'Cholesterol',
  MaxHR: 'Maximum Heart Rate',
  ExerciseAngina: 'Exercise-induced Angina',
  HeartDisease: 'Heart Disease Status'
};

data.forEach((d, i) => {
  d.id = i;
  d.Sex = d.Sex.toString();
  d.ChestPainType = d.ChestPainType.toString();
  d.ExerciseAngina = d.ExerciseAngina.toString();
  d.HeartDisease = d.HeartDisease ? 'Disease' : 'Healthy'; 
});

const columns = [
  'Age', 'Sex', 'ChestPainType', 'RestingBP', 'Cholesterol', 'MaxHR', 'ExerciseAngina', 'HeartDisease'
];
const columnTypes = {
  Age: 'quantitative',
  Sex: 'categorical',
  ChestPainType: 'categorical',
  RestingBP: 'quantitative',
  Cholesterol: 'quantitative',
  MaxHR: 'quantitative',
  ExerciseAngina: 'categorical',
  HeartDisease: 'categorical',
};

const colorScale = scaleOrdinal(schemeCategory10);
const colorValue = d => d.HeartDisease; 
const idValue = d => d.id;

export const main = (container, { state, setState }) => {
  const dimensions = observeResize({
    state,
    setState,
    container,
  });
  if (dimensions === null) return;
  const { width, height } = dimensions;

  if (!state.brushedIntervals) {
    setState(state => ({
      ...state,
      brushedIntervals: {},
    }));
    return;
  }
  const { brushedIntervals } = state;

  const updateBrushedInterval = ({ column, interval }) => {
    setState(state => ({
      ...state,
      brushedIntervals: {
        ...state.brushedIntervals,
        [column]: interval,
      },
    }));
  };

  const svg = select(container)
    .selectAll('svg')
    .data([null])
    .join('svg')
    .attr('width', width)
    .attr('height', height)
    .style('background', '#333333'); 

  svg.call(parallelCoordinates, {
    data,
    columns,
    columnTypes,
    colorValue,
    idValue,
    width,
    height,
    brushedIntervals,
    updateBrushedInterval,
    colorScale,
    labelMap
  });
};
